@@ -29,7 +29,6 @@
 
 #include <grl-metadata-key.h>
 #include <grl-media.h>
-#include <grl-media-box.h>
 #include <grl-definitions.h>
 #include <grl-plugin.h>
 #include <grl-operation-options.h>
@@ -111,10 +110,26 @@ typedef enum {
   GRL_OP_NOTIFY_CHANGE   = 1 << 9
 } GrlSupportedOps;
 
+ /**
+ * GrlSupportedMedia:
+ * @GRL_SUPPORTED_MEDIA_NONE: no media
+ * @GRL_SUPPORTED_MEDIA_AUDIO: audio media
+ * @GRL_SUPPORTED_MEDIA_VIDEO: video media
+ * @GRL_SUPPORTED_MEDIA_IMAGE: image media
+ * @GRL_SUPPORTED_MEDIA_ALL: any media
+ */
+typedef enum {
+  GRL_SUPPORTED_MEDIA_NONE  = 0,
+  GRL_SUPPORTED_MEDIA_AUDIO = (1 << 0),
+  GRL_SUPPORTED_MEDIA_VIDEO = (1 << 1),
+  GRL_SUPPORTED_MEDIA_IMAGE = (1 << 2),
+  GRL_SUPPORTED_MEDIA_ALL   = (GRL_SUPPORTED_MEDIA_AUDIO | GRL_SUPPORTED_MEDIA_VIDEO | GRL_SUPPORTED_MEDIA_IMAGE)
+} GrlSupportedMedia;
+
 /**
  * GrlSourceChangeType:
  * @GRL_CONTENT_CHANGED: content has changed. It is used when any property of
- * #GrlMedia has changed, or in case of #GrlMediaBox, if several children have
+ * #GrlMedia has changed, or in case of containers, if several children have
  * been added and removed.
  * @GRL_CONTENT_ADDED: new content has been added.
  * @GRL_CONTENT_REMOVED: content has been removed
@@ -363,7 +378,7 @@ typedef struct {
  */
 typedef struct {
   GrlSource *source;
-  GrlMediaBox *parent;
+  GrlMedia *parent;
   GrlMedia *media;
   GrlSourceStoreCb callback;
   gpointer user_data;
@@ -583,14 +598,14 @@ void grl_source_remove_sync (GrlSource *source,
                              GError **error);
 
 void grl_source_store (GrlSource *source,
-                       GrlMediaBox *parent,
+                       GrlMedia *parent,
                        GrlMedia *media,
                        GrlWriteFlags flags,
                        GrlSourceStoreCb callback,
                        gpointer user_data);
 
 void grl_source_store_sync (GrlSource *source,
-                            GrlMediaBox *parent,
+                            GrlMedia *parent,
                             GrlMedia *media,
                             GrlWriteFlags flags,
                             GError **error);
@@ -636,7 +651,7 @@ GrlPlugin *grl_source_get_plugin (GrlSource *source);
 
 gint grl_source_get_rank (GrlSource *source);
 
-GrlMediaType grl_source_get_supported_media (GrlSource *source);
+GrlSupportedMedia grl_source_get_supported_media (GrlSource *source);
 
 const char ** grl_source_get_tags (GrlSource *source);
 
