@@ -1,9 +1,9 @@
 
 /* Generated data (by glib-mkenums) */
 
-#include "grl-type-builtins.h"
-#include "./grl-source.h"
+#include <grl-type-builtins.h>
 /* enumerations from "./grl-source.h" */
+#include "./grl-source.h"
 GType
 grl_supported_ops_get_type (void)
 {
@@ -63,6 +63,7 @@ grl_source_change_type_get_type (void)
 }
 
 /* enumerations from "./grl-caps.h" */
+#include "./grl-caps.h"
 GType
 grl_type_filter_get_type (void)
 {
@@ -82,6 +83,7 @@ grl_type_filter_get_type (void)
 }
 
 /* enumerations from "./grl-operation-options.h" */
+#include "./grl-operation-options.h"
 GType
 grl_resolution_flags_get_type (void)
 {
@@ -115,6 +117,7 @@ grl_write_flags_get_type (void)
 }
 
 /* enumerations from "./grl-metadata-key.h" */
+#include "./grl-metadata-key.h"
 GType
 grl_media_type_get_type (void)
 {
@@ -134,6 +137,7 @@ grl_media_type_get_type (void)
 }
 
 /* enumerations from "./data/grl-media.h" */
+#include "./data/grl-media.h"
 GType
 grl_media_serialize_type_get_type (void)
 {
