@@ -11,6 +11,8 @@ G_BEGIN_DECLS
 /* enumerations from "./grl-source.h" */
 GType grl_supported_ops_get_type (void) G_GNUC_CONST;
 #define GRL_TYPE_SUPPORTED_OPS (grl_supported_ops_get_type())
+GType grl_supported_media_get_type (void) G_GNUC_CONST;
+#define GRL_TYPE_SUPPORTED_MEDIA (grl_supported_media_get_type())
 GType grl_source_change_type_get_type (void) G_GNUC_CONST;
 #define GRL_TYPE_SOURCE_CHANGE_TYPE (grl_source_change_type_get_type())
 
@@ -24,11 +26,13 @@ GType grl_resolution_flags_get_type (void) G_GNUC_CONST;
 GType grl_write_flags_get_type (void) G_GNUC_CONST;
 #define GRL_TYPE_WRITE_FLAGS (grl_write_flags_get_type())
 
+/* enumerations from "./grl-metadata-key.h" */
+GType grl_media_type_get_type (void) G_GNUC_CONST;
+#define GRL_TYPE_MEDIA_TYPE (grl_media_type_get_type())
+
 /* enumerations from "./data/grl-media.h" */
 GType grl_media_serialize_type_get_type (void) G_GNUC_CONST;
 #define GRL_TYPE_MEDIA_SERIALIZE_TYPE (grl_media_serialize_type_get_type())
-GType grl_media_type_get_type (void) G_GNUC_CONST;
-#define GRL_TYPE_MEDIA_TYPE (grl_media_type_get_type())
 G_END_DECLS
 
 #endif /* _GRL_TYPE_BUILTINS_H_ */
